[GRASS-SVN] r33598 - in grass/trunk: db/base display/d.grid display/d.thematic.area doc/vector/v.example general/g.mapset general/g.proj gui/wxpython/gui_modules imagery/i.ortho.photo/photo.2image imagery/i.ortho.photo/photo.2target imagery/i.points imagery/i.vpoints lib/db/dbmi_client lib/db/dbmi_driver lib/gis lib/gpde lib/ogsf lib/proj lib/sites lib/vector/Vlib lib/vector/diglib locale/templates raster/r.gwflow raster/r.le/r.le.patch raster/r.out.arc raster/r.out.gdal raster/r.to.vect scripts/d.vect.thematic scripts/r.tileset scripts/v.what.vect vector/v.clean vector/v.distance vector/v.edit vector/v.label.sa

svn_grass at osgeo.org svn_grass at osgeo.org
Mon Sep 29 13:31:57 EDT 2008


Author: glynn
Date: 2008-09-29 13:31:56 -0400 (Mon, 29 Sep 2008)
New Revision: 33598

Modified:
   grass/trunk/db/base/copy.c
   grass/trunk/display/d.grid/main.c
   grass/trunk/display/d.thematic.area/main.c
   grass/trunk/doc/vector/v.example/main.c
   grass/trunk/general/g.mapset/main.c
   grass/trunk/general/g.proj/datumtrans.c
   grass/trunk/gui/wxpython/gui_modules/menudata.py
   grass/trunk/gui/wxpython/gui_modules/nviz_tools.py
   grass/trunk/gui/wxpython/gui_modules/render.py
   grass/trunk/gui/wxpython/gui_modules/toolbars.py
   grass/trunk/gui/wxpython/gui_modules/toolbox.py
   grass/trunk/imagery/i.ortho.photo/photo.2image/main.c
   grass/trunk/imagery/i.ortho.photo/photo.2image/where.c
   grass/trunk/imagery/i.ortho.photo/photo.2target/main.c
   grass/trunk/imagery/i.ortho.photo/photo.2target/where.c
   grass/trunk/imagery/i.points/main.c
   grass/trunk/imagery/i.vpoints/drawvect.c
   grass/trunk/imagery/i.vpoints/main.c
   grass/trunk/imagery/i.vpoints/where.c
   grass/trunk/lib/db/dbmi_client/copy_tab.c
   grass/trunk/lib/db/dbmi_client/start.c
   grass/trunk/lib/db/dbmi_driver/driver.c
   grass/trunk/lib/gis/cats.c
   grass/trunk/lib/gis/env.c
   grass/trunk/lib/gis/error.c
   grass/trunk/lib/gis/get_window.c
   grass/trunk/lib/gis/gisinit.c
   grass/trunk/lib/gpde/N_arrays_io.c
   grass/trunk/lib/ogsf/gsd_legend.c
   grass/trunk/lib/proj/convert.c
   grass/trunk/lib/sites/sites.c
   grass/trunk/lib/vector/Vlib/area.c
   grass/trunk/lib/vector/Vlib/break_lines.c
   grass/trunk/lib/vector/Vlib/break_polygons.c
   grass/trunk/lib/vector/Vlib/bridges.c
   grass/trunk/lib/vector/Vlib/buffer.c
   grass/trunk/lib/vector/Vlib/build.c
   grass/trunk/lib/vector/Vlib/build_nat.c
   grass/trunk/lib/vector/Vlib/dangles.c
   grass/trunk/lib/vector/Vlib/remove_duplicates.c
   grass/trunk/lib/vector/Vlib/snap.c
   grass/trunk/lib/vector/diglib/plus_struct.c
   grass/trunk/locale/templates/
   grass/trunk/raster/r.gwflow/main.c
   grass/trunk/raster/r.le/r.le.patch/patch.c
   grass/trunk/raster/r.out.arc/main.c
   grass/trunk/raster/r.out.gdal/main.c
   grass/trunk/raster/r.to.vect/main.c
   grass/trunk/scripts/d.vect.thematic/d.vect.thematic
   grass/trunk/scripts/r.tileset/r.tileset
   grass/trunk/scripts/v.what.vect/v.what.vect
   grass/trunk/scripts/v.what.vect/v.what.vect.py
   grass/trunk/vector/v.clean/proto.h
   grass/trunk/vector/v.distance/main.c
   grass/trunk/vector/v.edit/a2b.c
   grass/trunk/vector/v.edit/args.c
   grass/trunk/vector/v.label.sa/main.c
Log:
Fix various typos
Add svn:ignore property to locale/templates


Modified: grass/trunk/db/base/copy.c
===================================================================
--- grass/trunk/db/base/copy.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/db/base/copy.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -34,7 +34,7 @@
     module->keywords = _("database, attribute table, SQL");
     module->label = _("Copy a table.");
     module->description =
-	_("Either 'from_table' (optionaly with 'where') can be used "
+	_("Either 'from_table' (optionally with 'where') can be used "
 	  "or 'select' option, but not 'from_table' and 'select' at the same time.");
     
     from_driver = G_define_standard_option(G_OPT_DB_DRIVER);

Modified: grass/trunk/display/d.grid/main.c
===================================================================
--- grass/trunk/display/d.grid/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/display/d.grid/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -151,7 +151,7 @@
 
     mark_type = MARK_GRID;
     if (cross->answer && fiducial->answer)
-	G_fatal_error(_("Chose a single mark style"));
+	G_fatal_error(_("Choose a single mark style"));
     if (cross->answer)
 	mark_type = MARK_CROSS;
     if (fiducial->answer)

Modified: grass/trunk/display/d.thematic.area/main.c
===================================================================
--- grass/trunk/display/d.thematic.area/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/display/d.thematic.area/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -75,7 +75,7 @@
     module = G_define_module();
     module->keywords = _("display");
     module->description =
-	_("Displays a thematic vector area map in the active"
+	_("Displays a thematic vector area map in the active "
 	  "frame on the graphics monitor.");
 
     map_opt = G_define_standard_option(G_OPT_V_MAP);

Modified: grass/trunk/doc/vector/v.example/main.c
===================================================================
--- grass/trunk/doc/vector/v.example/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/doc/vector/v.example/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -164,7 +164,7 @@
 	    /* Now execute query */
 	    if (db_open_select_cursor(driver, &dbsql, &cursor, DB_SEQUENTIAL)
 		!= DB_OK)
-		G_warning(_("Unabale to get attribute data for cat %d"), cat);
+		G_warning(_("Unable to get attribute data for cat %d"), cat);
 	    else {
 		/* Result count */
 		nrows = db_get_num_rows(&cursor);

Modified: grass/trunk/general/g.mapset/main.c
===================================================================
--- grass/trunk/general/g.mapset/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/general/g.mapset/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -151,7 +151,7 @@
     /* Check if the mapset is in use */
     gis_lock = getenv("GIS_LOCK");
     if (!gis_lock)
-	G_fatal_error(_("Unable to read GIS_LOCK enviroment variable"));
+	G_fatal_error(_("Unable to read GIS_LOCK environment variable"));
 
     G_asprintf(&lock_prog, "%s/etc/lock", G_gisbase());
 

Modified: grass/trunk/general/g.proj/datumtrans.c
===================================================================
--- grass/trunk/general/g.proj/datumtrans.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/general/g.proj/datumtrans.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -86,7 +86,7 @@
 
 	    if (datumtrans > paramsets)
 		G_fatal_error
-		    ("Invalid tranformation number %d; valid range is 1 to %d",
+		    ("Invalid transformation number %d; valid range is 1 to %d",
 		     datumtrans, paramsets);
 
 	    list = GPJ_get_datum_transform_by_name(datum);

Modified: grass/trunk/gui/wxpython/gui_modules/menudata.py
===================================================================
--- grass/trunk/gui/wxpython/gui_modules/menudata.py	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/gui/wxpython/gui_modules/menudata.py	2008-09-29 17:31:56 UTC (rev 33598)
@@ -1835,7 +1835,7 @@
                                 ("","","", ""),
 
                                 (_("Copy table"),
-                                 _("Copy a table. Either 'from_table' (optionaly with 'where') can be used or 'select' option, but not 'from_table' and 'select' at the same time."),
+                                 _("Copy a table. Either 'from_table' (optionally with 'where') can be used or 'select' option, but not 'from_table' and 'select' at the same time."),
                                  "self.OnMenuCmd",
                                  "db.copy"),
 

Modified: grass/trunk/gui/wxpython/gui_modules/nviz_tools.py
===================================================================
--- grass/trunk/gui/wxpython/gui_modules/nviz_tools.py	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/gui/wxpython/gui_modules/nviz_tools.py	2008-09-29 17:31:56 UTC (rev 33598)
@@ -578,9 +578,9 @@
         gridSizer.Add(item=display, flag=wx.ALIGN_CENTER_VERTICAL,
                       pos=(0, 7))
 
-        # hight
+        # height
         gridSizer.Add(item=wx.StaticText(parent=panel, id=wx.ID_ANY,
-                                         label=_("Hight above surface:")),
+                                         label=_("Height above surface:")),
                       pos=(1, 0), flag=wx.ALIGN_CENTER_VERTICAL,
                       span=(1, 2))
         
@@ -685,7 +685,7 @@
 
         # high
         gridSizer.Add(item=wx.StaticText(parent=panel, id=wx.ID_ANY,
-                                         label=_("Hight above surface:")),
+                                         label=_("Height above surface:")),
                       pos=(1, 0), flag=wx.ALIGN_CENTER_VERTICAL,
                       span=(1, 2))
         
@@ -1211,7 +1211,7 @@
 
         # icon width
         gridSizer.Add(item=wx.StaticText(parent=panel, id=wx.ID_ANY,
-                                         label=_("Witdh:")),
+                                         label=_("Width:")),
                       pos=(row, 2), flag=wx.ALIGN_CENTER_VERTICAL)
         
         iwidth = wx.SpinCtrl(parent=panel, id=wx.ID_ANY, size=(65, -1),

Modified: grass/trunk/gui/wxpython/gui_modules/render.py
===================================================================
--- grass/trunk/gui/wxpython/gui_modules/render.py	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/gui/wxpython/gui_modules/render.py	2008-09-29 17:31:56 UTC (rev 33598)
@@ -360,7 +360,7 @@
         #
         # environment settings
         #
-        # enviroment variables, like MAPSET, LOCATION_NAME, etc.
+        # environment variables, like MAPSET, LOCATION_NAME, etc.
         self.env         = {}
         # path to external gisrc
         self.gisrc = gisrc
@@ -560,7 +560,7 @@
         """
         Get region settings (g.region -upgc)
 
-        Optionaly extent, raster or vector map layer can be given.
+        Optionally extent, raster or vector map layer can be given.
 
         @param rast raster name or None
         @param vect vector name or None

Modified: grass/trunk/gui/wxpython/gui_modules/toolbars.py
===================================================================
--- grass/trunk/gui/wxpython/gui_modules/toolbox.py	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/gui/wxpython/gui_modules/toolbox.py	2008-09-29 17:31:56 UTC (rev 33598)
@@ -14,7 +14,7 @@
 </qgisgrass>
 """
 test_modules = {"g.gisenv":"""
-<qgisgrassmodule label="GRASS enviroment variables" module="g.gisenv">
+<qgisgrassmodule label="GRASS environment variables" module="g.gisenv">
 </qgisgrassmodule>
 ""","r.to.vect.area":"""
 <qgisgrassmodule label="Convert a raster to vector areas" module="r.to.vect">

Modified: grass/trunk/imagery/i.ortho.photo/photo.2image/main.c
===================================================================
--- grass/trunk/imagery/i.ortho.photo/photo.2image/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/imagery/i.ortho.photo/photo.2image/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -88,7 +88,7 @@
 	group.photo_points.count = 0;
     G_suppress_warnings(0);
 
-    /* determine tranformation equation */
+    /* determine transformation equation */
     Compute_equation();
 
     signal(SIGINT, SIG_IGN);

Modified: grass/trunk/imagery/i.ortho.photo/photo.2image/where.c
===================================================================
--- grass/trunk/imagery/i.ortho.photo/photo.2image/where.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/imagery/i.ortho.photo/photo.2image/where.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -57,7 +57,7 @@
     sprintf(buf, "North: %10.2f", n1);
     Curses_write_window(w1, 4, 3, buf);
 
-    /* if tranformation equation is useable, determine point via equation */
+    /* if transformation equation is useable, determine point via equation */
     if (group.ref_equation_stat <= 0)
 	return 1;
 

Modified: grass/trunk/imagery/i.ortho.photo/photo.2target/main.c
===================================================================
--- grass/trunk/imagery/i.ortho.photo/photo.2target/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/imagery/i.ortho.photo/photo.2target/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -134,7 +134,7 @@
 	    G_warning(msg);
 	}
 
-    /* get target info and enviroment */
+    /* get target info and environment */
     G_suppress_warnings(1);
     get_target();
     find_target_files();
@@ -153,7 +153,7 @@
     }
     G_suppress_warnings(0);
 
-    /* determine tranformation equation */
+    /* determine transformation equation */
     Compute_ref_equation();
 
     /* read group control points, format: image x,y,cfl; target E,N,Z */
@@ -169,7 +169,7 @@
 			 &group.control_points, group.E12, group.N12);
     ********/
 
-    /* determine tranformation equation */
+    /* determine transformation equation */
     fprintf(stderr, "Computing equations ...\n");
     if (group.control_points.count > 0)
 	Compute_ortho_equation();

Modified: grass/trunk/imagery/i.ortho.photo/photo.2target/where.c
===================================================================
--- grass/trunk/imagery/i.ortho.photo/photo.2target/where.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/imagery/i.ortho.photo/photo.2target/where.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -51,7 +51,7 @@
     sprintf(buf, "IMAGE Y: %10.2f", n1);
     Curses_write_window(w1, 4, 3, buf);
 
-    /* if tranformation equation is useable, determine point via equation */
+    /* if transformation equation is useable, determine point via equation */
     if (group.ref_equation_stat <= 0)
 	return 1;
 

Modified: grass/trunk/imagery/i.points/main.c
===================================================================
--- grass/trunk/imagery/i.points/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/imagery/i.points/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -103,7 +103,7 @@
     /* write group files to group list file */
     prepare_group_list();
 
-    /* get target info and enviroment */
+    /* get target info and environment */
     get_target();
     find_target_files();
 
@@ -113,7 +113,7 @@
 	group.points.count = 0;
     G_suppress_warnings(0);
 
-    /* determine tranformation equation */
+    /* determine transformation equation */
     Compute_equation();
 
 

Modified: grass/trunk/imagery/i.vpoints/drawvect.c
===================================================================
--- grass/trunk/imagery/i.vpoints/drawvect.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/imagery/i.vpoints/drawvect.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -46,7 +46,7 @@
 
 static int drawvect(int zoomit,	/* -1 = refresh, 0 = new image, 1 = zoom, 2 = warp */
 		    View * zoom_view, double E[], double N[], int trans_order)
-{				/* order of tranformation if warping vectors */
+{				/* order of transformation if warping vectors */
     int stat = 0;
     int i;
     char name[GNAME_MAX], mapset[GMAPSET_MAX];

Modified: grass/trunk/imagery/i.vpoints/main.c
===================================================================
--- grass/trunk/imagery/i.vpoints/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/imagery/i.vpoints/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -98,7 +98,7 @@
     /* write group files to group list file */
     prepare_group_list();
 
-    /* get target info and enviroment */
+    /* get target info and environment */
     get_target();
     find_target_files();
 
@@ -108,7 +108,7 @@
 	group.points.count = 0;
     G_suppress_warnings(0);
 
-    /* determine tranformation equation */
+    /* determine transformation equation */
     CRS_Compute_equation(1);
 
     signal(SIGINT, SIG_IGN);

Modified: grass/trunk/imagery/i.vpoints/where.c
===================================================================
--- grass/trunk/imagery/i.vpoints/where.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/imagery/i.vpoints/where.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -54,7 +54,7 @@
     sprintf(buf, "N = %10.2f", n1);
     Curses_write_window(INFO_WINDOW, 18, 3, buf);
 
-    /* if tranformation equation is useable, determine point via equation */
+    /* if transformation equation is useable, determine point via equation */
     if (group.equation_stat <= 0 || windnum == 2) {
 	Curses_write_window(INFO_WINDOW, 15, 18, "           ");
 	Curses_write_window(INFO_WINDOW, 17, 18, "                 ");

Modified: grass/trunk/lib/db/dbmi_client/copy_tab.c
===================================================================
--- grass/trunk/lib/db/dbmi_client/copy_tab.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/db/dbmi_client/copy_tab.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -154,7 +154,7 @@
 	const char *tblname = db_get_string(&tblnames[i]);
 
 	if (strcmp(to_tblname, tblname) == 0) {
-	    G_warning(_("Table <%s> already existsin database <%s>"),
+	    G_warning(_("Table <%s> already exists in database <%s>"),
 		      to_dbname, to_dbname);
 	    db_close_database_shutdown_driver(to_driver);
 	    if (from_driver != to_driver)

Modified: grass/trunk/lib/db/dbmi_client/start.c
===================================================================
--- grass/trunk/lib/db/dbmi_client/start.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/db/dbmi_client/start.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -56,7 +56,7 @@
     int stdin_fd, stdout_fd;
 #endif
 
-    /* Set some enviroment variables which are later read by driver.
+    /* Set some environment variables which are later read by driver.
      * This is necessary when application is running without GISRC file and all
      * gis variables are set by application. 
      * Even if GISRC is set, application may change some variables during runtime,
@@ -82,7 +82,7 @@
     }
     else {
 	/* Warning: GISRC_MODE_MEMORY _must_ be set to G_GISRC_MODE_FILE, because the module can be 
-	 *          run from an application which previously set enviroment variable to G_GISRC_MODE_MEMORY */
+	 *          run from an application which previously set environment variable to G_GISRC_MODE_MEMORY */
 	sprintf(ebuf, "%d", G_GISRC_MODE_FILE);
 	G_putenv("GRASS_DB_DRIVER_GISRC_MODE", ebuf);
     }

Modified: grass/trunk/lib/db/dbmi_driver/driver.c
===================================================================
--- grass/trunk/lib/db/dbmi_driver/driver.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/db/dbmi_driver/driver.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -44,7 +44,7 @@
     FILE *send, *recv;
     char *modestr;
 
-    /* Read and set enviroment variables, see dbmi_client/start.c */
+    /* Read and set environment variables, see dbmi_client/start.c */
     if ((modestr = getenv("GRASS_DB_DRIVER_GISRC_MODE"))) {
 	int mode;
 

Modified: grass/trunk/lib/gis/cats.c
===================================================================
--- grass/trunk/lib/gis/cats.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/gis/cats.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -52,7 +52,7 @@
  *       a blank line for the fmt will effectively suppress automatic
  *       label generation
  *
- * Note: quant rules of Categories structures are heavily dependant
+ * Note: quant rules of Categories structures are heavily dependent
  * on the fact that rules are stored in the same order they are entered.
  * since i-th rule and i-th label are entered at the same time, we
  * know that i-th rule maps fp range to i, thus we know for sure

Modified: grass/trunk/lib/gis/env.c
===================================================================
--- grass/trunk/lib/gis/env.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/gis/env.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -256,7 +256,7 @@
 }
 
 /**
-   \brief Get enviroment variable
+   \brief Get environment variable
 
    Calls G_fatal_error() if name not set.
 

Modified: grass/trunk/lib/gis/error.c
===================================================================
--- grass/trunk/lib/gis/error.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/gis/error.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -67,7 +67,7 @@
 /*!
  * \brief Print a message to stderr
  *
- * The output format depends on enviroment variable GRASS_MESSAGE_FORMAT
+ * The output format depends on environment variable GRASS_MESSAGE_FORMAT
  *
  * \param msg string (cannot be NULL)
  */
@@ -87,7 +87,7 @@
 /*!
  * \brief Print a message to stderr but only if module is in verbose mode
  *
- * The output format depends on enviroment variables
+ * The output format depends on environment variables
  *  GRASS_MESSAGE_FORMAT and GRASS_VERBOSE
  *
  * \param msg string (cannot be NULL)
@@ -111,7 +111,7 @@
  * Ususally just G_percent()/G_clicker() would be shown at this level.
  * This allows important non-error/warning messages to display as well.
  *
- * The output format depends on enviroment variables
+ * The output format depends on environment variables
  *  GRASS_MESSAGE_FORMAT and GRASS_VERBOSE
  *
  * \param msg string (cannot be NULL)
@@ -132,7 +132,7 @@
 /*!
  * \brief Print a fatal error message to stderr
  * 
- * The output format depends on enviroment variable
+ * The output format depends on environment variable
  * GRASS_MESSAGE_FORMAT
  *
  * By default, the message is handled by an internal routine which
@@ -161,7 +161,7 @@
 /*!
  * \brief Print a warning message to stderr
  * 
- * The output format depends on enviroment variable
+ * The output format depends on environment variable
  * GRASS_MESSAGE_FORMAT
  *
  * A warning message can be suppressed by G_suppress_warnings()
@@ -246,7 +246,7 @@
     return 0;
 }
 
-/* Print info to stderr and optionaly to log file and optionaly send mail */
+/* Print info to stderr and optionally to log file and optionally send mail */
 static int print_error(const char *msg, const int type)
 {
     static char *prefix_std[3];

Modified: grass/trunk/lib/gis/get_window.c
===================================================================
--- grass/trunk/lib/gis/get_window.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/gis/get_window.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -50,7 +50,7 @@
     static struct Cell_head dbwindow;
     char *regvar;
 
-    /* Optionaly read the region from enviroment variable */
+    /* Optionally read the region from environment variable */
     regvar = getenv("GRASS_REGION");
 
     if (regvar) {

Modified: grass/trunk/lib/gis/gisinit.c
===================================================================
--- grass/trunk/lib/gis/gisinit.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/gis/gisinit.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -135,7 +135,7 @@
     /* Set masking flag unknown */
     G__.auto_mask = -1;
 
-    /* set architecture dependant bit patterns for embeded null vals */
+    /* set architecture dependent bit patterns for embeded null vals */
     G__init_null_patterns();
 
     initialized = 1;

Modified: grass/trunk/lib/gpde/N_arrays_io.c
===================================================================
--- grass/trunk/lib/gpde/N_arrays_io.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/gpde/N_arrays_io.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -224,17 +224,17 @@
 	if (type == CELL_TYPE)
 	    if (!G_put_c_raster_row(map, rast)) {
 		G_unopen_cell(map);	/*unopen the new raster map */
-		G_fatal_error(_("Unable to write rast row %i"), y);
+		G_fatal_error(_("Unable to write raster row %i"), y);
 	    }
 	if (type == FCELL_TYPE)
 	    if (!G_put_f_raster_row(map, frast)) {
 		G_unopen_cell(map);	/*unopen the new raster map */
-		G_fatal_error(_("Unable to write rast row %i"), y);
+		G_fatal_error(_("Unable to write raster row %i"), y);
 	    }
 	if (type == DCELL_TYPE)
 	    if (!G_put_d_raster_row(map, drast)) {
 		G_unopen_cell(map);	/*unopen the new raster map */
-		G_fatal_error(_("Unable to write rast row %i"), y);
+		G_fatal_error(_("Unable to write raster row %i"), y);
 	    }
     }
 

Modified: grass/trunk/lib/ogsf/gsd_legend.c
===================================================================
--- grass/trunk/lib/ogsf/gsd_legend.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/ogsf/gsd_legend.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -520,7 +520,7 @@
 		    G_get_color((CELL) tdcell, &red, &green, &blue, &colors);
 
 		RGB_TO_INT(red, green, blue, colr);
-		if (discrete) {	/* draw black-white-black seperator */
+		if (discrete) {	/* draw black-white-black separator */
 		    if (k > 0) {
 			*dv1 -= 2. * incr;
 			*dv2 -= 2. * incr;

Modified: grass/trunk/lib/proj/convert.c
===================================================================
--- grass/trunk/lib/proj/convert.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/proj/convert.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -437,7 +437,7 @@
 				   "You may want to look into this."), datum);
 		    else if (datumtrans > paramsets) {
 
-			G_warning(_("Invalid tranformation number %d; valid range is 1 to %d. "
+			G_warning(_("Invalid transformation number %d; valid range is 1 to %d. "
 				   "Leaving datum transform parameters unspecified."),
 				  datumtrans, paramsets);
 			datumtrans = 0;

Modified: grass/trunk/lib/sites/sites.c
===================================================================
--- grass/trunk/lib/sites/sites.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/sites/sites.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -1041,7 +1041,7 @@
 /*********************************************/
 
 char *G_site_format(const Site * s, const char *fs, int id)
-/* sprintf analog to G_site_put with the addition of a field seperator fs 
+/* sprintf analog to G_site_put with the addition of a field separator fs 
    and option of printing site attribute identifiers
  */
 {

Modified: grass/trunk/lib/vector/Vlib/area.c
===================================================================
--- grass/trunk/lib/vector/Vlib/area.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/area.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -50,7 +50,7 @@
     Area = Plus->Area[area];
 
     if (Area == NULL) {		/* dead area */
-	G_warning(_("Attempt to read points of nonexisting area"));
+	G_warning(_("Attempt to read points of nonexistent area"));
 	return -1;		/* error , because we should not read dead areas */
     }
 

Modified: grass/trunk/lib/vector/Vlib/break_lines.c
===================================================================
--- grass/trunk/lib/vector/Vlib/break_lines.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/break_lines.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -46,7 +46,7 @@
    \brief Break selected lines in vector map at each intersection.
 
    Breaks selected lines specified by type in vector map. Points at
-   intersections may be optionaly written to error map. Input vector map
+   intersections may be optionally written to error map. Input vector map
    must be opened on level 2 for update at least on GV_BUILD_BASE.
 
    The function also breaks lines forming collapsed loop, for example

Modified: grass/trunk/lib/vector/Vlib/break_polygons.c
===================================================================
--- grass/trunk/lib/vector/Vlib/break_polygons.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/break_polygons.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -44,7 +44,7 @@
 /*!
    \brief Break polygons in vector map.
 
-   Breaks lines specified by type in vector map. Points at intersections may be optionaly 
+   Breaks lines specified by type in vector map. Points at intersections may be optionally 
    written to error map. Input map must be opened on level 2 for update at least on GV_BUILD_BASE.
 
    Function is optimized for closed polygons rigs (e.g. imported from OGR) but with clean geometry -

Modified: grass/trunk/lib/vector/Vlib/bridges.c
===================================================================
--- grass/trunk/lib/vector/Vlib/bridges.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/bridges.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -32,7 +32,7 @@
    Remove bridges (type boundary) connecting areas to islands or 2 islands.
    Islands and areas must be already clean, i.e. without dangles.
    Bridge may be formed by more lines.
-   Optionaly deleted bridges are written to error map. 
+   Optionally deleted bridges are written to error map. 
    Input map must be opened on level 2 for update at least on level GV_BUILD_BASE
 
    \param Map input map where bridges are deleted
@@ -54,7 +54,7 @@
    Change the type of bridges (type boundary) connecting areas to islands or 2 islands.
    Islands and areas must be already clean, i.e. without dangles.
    Bridge may be formed by more lines.
-   Optionaly changed bridges are written to error map. 
+   Optionally changed bridges are written to error map. 
    Input map must be opened on level 2 for update at least on level GV_BUILD_BASE.
 
    \param Map input map where bridges are changed

Modified: grass/trunk/lib/vector/Vlib/buffer.c
===================================================================
--- grass/trunk/lib/vector/Vlib/buffer.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/buffer.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -117,7 +117,7 @@
 /* clean_parallel - clean parallel line created by parallel_line:
  ** - looking for loops and if loop doesn't contain any other loop
  **   and centroid of loop is in buffer removes this loop (repeated)
- ** - optionaly removes all end points in buffer
+ ** - optionally removes all end points in buffer
  *    parameters:
  *      Points - parallel line
  *      origPoints - original line

Modified: grass/trunk/lib/vector/Vlib/build.c
===================================================================
--- grass/trunk/lib/vector/Vlib/build.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/build.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -93,7 +93,7 @@
 
    Should only be used in special cases of vector processing.
 
-   This functions optionaly builds only some parts of topology. Highest level is specified by build
+   This functions optionally builds only some parts of topology. Highest level is specified by build
    parameter which may be:
    - GV_BUILD_NONE - nothing is build;
    - GV_BUILD_BASE - basic topology, nodes, spatial index;

Modified: grass/trunk/lib/vector/Vlib/build_nat.c
===================================================================
--- grass/trunk/lib/vector/Vlib/build_nat.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/build_nat.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -148,7 +148,7 @@
     plus = &(Map->plus);
 
     if (plus->Isle[isle] == NULL) {
-	G_warning(_("Request to find area outside nonexisting isle"));
+	G_warning(_("Request to find area outside nonexistent isle"));
 	return 0;
     }
 

Modified: grass/trunk/lib/vector/Vlib/dangles.c
===================================================================
--- grass/trunk/lib/vector/Vlib/dangles.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/dangles.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -39,7 +39,7 @@
    such string of lines is taken as one dangle and either deleted are
    all parts or nothing.
 
-   Optionaly deleted dangles are written to error map. 
+   Optionally deleted dangles are written to error map. 
 
    Input map must be opened on level 2 for update.
 
@@ -67,7 +67,7 @@
    no other boundary.  If a dangle is formed by more boundaries, such
    string of boundaries is taken as one dangle.
 
-   Optionaly deleted dangles are written to error map. 
+   Optionally deleted dangles are written to error map. 
 
    Input map must be opened on level 2 for update at least on GV_BUILD_BASE.
 
@@ -114,9 +114,9 @@
    Line is considered to be a dangle if on at least one end node is no
    other line of given type(s). If a dangle is formed by more lines,
    such string of lines is taken as one dangle and either deleted are
-   all parts or nothing.  Optionaly, if chtype is set to 1, only
+   all parts or nothing.  Optionally, if chtype is set to 1, only
    GV_BOUNDARY are checked for dangles, and if dangle is found lines
-   are not deleted but rewritten with type GVLINE.  Optionaly deleted
+   are not deleted but rewritten with type GVLINE.  Optionally deleted
    dangles are written to error map.  Input map must be opened on level
    2 for update at least on GV_BUILD_BASE.
 

Modified: grass/trunk/lib/vector/Vlib/remove_duplicates.c
===================================================================
--- grass/trunk/lib/vector/Vlib/remove_duplicates.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/remove_duplicates.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -25,7 +25,7 @@
 /*!
    \brief Remove duplicate lines from vector map.
 
-   Remove duplicate lines of given types from vector map. Duplicate lines may be optionaly 
+   Remove duplicate lines of given types from vector map. Duplicate lines may be optionally 
    written to error map. Input map must be opened on level 2 for update. Categories are merged.
 
    \param Map vector map where duplicate lines will be deleted

Modified: grass/trunk/lib/vector/Vlib/snap.c
===================================================================
--- grass/trunk/lib/vector/Vlib/snap.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/Vlib/snap.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -55,7 +55,7 @@
  * 
  * \warning Lines are not necessarily snapped to nearest vertex, but to vertex in threshold! 
  *
- * Lines showing how vertices were snapped may be optionaly written to error map. 
+ * Lines showing how vertices were snapped may be optionally written to error map. 
  * Input map must be opened on level 2 for update at least on GV_BUILD_BASE.
  *
  * \param[in] Map input map where vertices will be snapped

Modified: grass/trunk/lib/vector/diglib/plus_struct.c
===================================================================
--- grass/trunk/lib/vector/diglib/plus_struct.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/lib/vector/diglib/plus_struct.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -25,7 +25,7 @@
  * if you dont want it written out, then dont call these routines
  * ie  check for deleted status before calling a write routine
  * in as much as it would be nice to hide that code in here,
- * this is a library routine and we chose to make it dependant on
+ * this is a library routine and we chose to make it dependent on
  * as few external files as possible 
  */
 


Property changes on: grass/trunk/locale/templates
___________________________________________________________________
Name: svn:ignore
   + *.pot


Modified: grass/trunk/raster/r.gwflow/main.c
===================================================================
--- grass/trunk/raster/r.gwflow/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/raster/r.gwflow/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -147,7 +147,7 @@
     param.river_bed->type = TYPE_STRING;
     param.river_bed->required = NO;
     param.river_bed->gisprompt = "old,raster,raster";
-    param.river_bed->description = _("The hight of the river bed in [m]");
+    param.river_bed->description = _("The height of the river bed in [m]");
 
     param.river_head = G_define_option();
     param.river_head->key = "river_head";
@@ -170,7 +170,7 @@
     param.drain_bed->type = TYPE_STRING;
     param.drain_bed->required = NO;
     param.drain_bed->gisprompt = "old,raster,raster";
-    param.drain_bed->description = _("The hight of the drainage bed in [m]");
+    param.drain_bed->description = _("The height of the drainage bed in [m]");
 
     param.drain_leak = G_define_option();
     param.drain_leak->key = "drain_leak";

Modified: grass/trunk/raster/r.le/r.le.patch/patch.c
===================================================================
--- grass/trunk/raster/r.le/r.le.patch/patch.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/raster/r.le/r.le.patch/patch.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -1594,7 +1594,7 @@
 
     /*Variables
        EXTERNAL
-       recl_count = an array containg the number of elements in each
+       recl_count = an array containing the number of elements in each
        row of the reclass table
        IN
        att     = the attribute value

Modified: grass/trunk/raster/r.out.arc/main.c
===================================================================
--- grass/trunk/raster/r.out.arc/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/raster/r.out.arc/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -86,7 +86,7 @@
     flag.noheader->key = 'h';
     flag.noheader->description = _("Suppress printing of header information");
 
-    /* Added to optionaly produce a single line output.     -- emes -- 12.10.92 */
+    /* Added to optionally produce a single line output.     -- emes -- 12.10.92 */
     flag.singleline = G_define_flag();
     flag.singleline->key = '1';
     flag.singleline->description =

Modified: grass/trunk/raster/r.out.gdal/main.c
===================================================================
--- grass/trunk/raster/r.out.gdal/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/raster/r.out.gdal/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -336,12 +336,12 @@
 
     if (n_nulls > 0) {
 	if (maptype == CELL_TYPE)
-	    G_warning(_("Input raster map constains cells with NULL-value (no-data). "
+	    G_warning(_("Input raster map contains cells with NULL-value (no-data). "
 		       "The value %d was used to represent no-data values in the input map."
 		       "You can specify nodata value by %s parameter."),
 		      (int)nodataval, nodatakey);
 	else
-	    G_warning(_("Input raster map constains cells with NULL-value (no-data). "
+	    G_warning(_("Input raster map contains cells with NULL-value (no-data). "
 		       "The value %g was used to represent no-data values in the input map."
 		       "You can specify nodata value by %s parameter."),
 		      nodataval, nodatakey);

Modified: grass/trunk/raster/r.to.vect/main.c
===================================================================
--- grass/trunk/raster/r.to.vect/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/raster/r.to.vect/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -243,7 +243,7 @@
 	Vect_build(&Map, stderr);
 
 
-    /* insert cats and optionaly labels if raster cats were used */
+    /* insert cats and optionally labels if raster cats were used */
     if (driver && value_flag) {
 	char buf[1000];
 	int c, i, cat, fidx, ncats, lastcat, tp, id;

Modified: grass/trunk/scripts/d.vect.thematic/d.vect.thematic
===================================================================
--- grass/trunk/scripts/d.vect.thematic/d.vect.thematic	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/scripts/d.vect.thematic/d.vect.thematic	2008-09-29 17:31:56 UTC (rev 33598)
@@ -17,7 +17,7 @@
 
 
 #%Module
-#%  description: Displays thematic vectormap
+#%  description: Displays thematic vector map
 #%  keywords: display, legend
 #%End
 #%option

Modified: grass/trunk/scripts/r.tileset/r.tileset
===================================================================
--- grass/trunk/scripts/r.tileset/r.tileset	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/scripts/r.tileset/r.tileset	2008-09-29 17:31:56 UTC (rev 33598)
@@ -107,7 +107,7 @@
 #%option
 #% key: fs
 #% type: string
-#% description: Output field seperator
+#% description: Output field separator
 #% answer:|
 #%end
 #%option

Modified: grass/trunk/scripts/v.what.vect/v.what.vect
===================================================================
--- grass/trunk/scripts/v.what.vect/v.what.vect	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/scripts/v.what.vect/v.what.vect	2008-09-29 17:31:56 UTC (rev 33598)
@@ -51,7 +51,7 @@
 #%option
 #% key: qlayer
 #% type: integer
-#% description: Layer of the query vector containg data
+#% description: Layer of the query vector containing data
 #% answer: 1
 #% required : no
 #%end

Modified: grass/trunk/scripts/v.what.vect/v.what.vect.py
===================================================================
--- grass/trunk/scripts/v.what.vect/v.what.vect.py	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/scripts/v.what.vect/v.what.vect.py	2008-09-29 17:31:56 UTC (rev 33598)
@@ -50,7 +50,7 @@
 #%option
 #% key: qlayer
 #% type: integer
-#% description: Layer of the query vector containg data
+#% description: Layer of the query vector containing data
 #% answer: 1
 #% required : no
 #%end

Modified: grass/trunk/vector/v.clean/proto.h
===================================================================
--- grass/trunk/vector/v.clean/proto.h	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/vector/v.clean/proto.h	2008-09-29 17:31:56 UTC (rev 33598)
@@ -10,7 +10,7 @@
 #define TOOL_PRUNE   10		/* remove vertices in threshold from lines and boundaries */
 #define TOOL_RMAREA  11		/* remove small areas */
 #define TOOL_RMSA    12		/* remove small angles between lines at nodes */
-#define TOOL_RMLINE  13		/* remove all line or boudaries of zero length */
+#define TOOL_RMLINE  13		/* remove all line or boundaries of zero length */
 
 #define SEP \
     "--------------------------------------------------"

Modified: grass/trunk/vector/v.distance/main.c
===================================================================
--- grass/trunk/vector/v.distance/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/vector/v.distance/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -426,7 +426,7 @@
 		     && (fctype == DB_C_TYPE_STRING ||
 			 fctype == DB_C_TYPE_DATETIME))
 		    ) {
-		    G_fatal_error(_("Incomatible column types"));
+		    G_fatal_error(_("Incompatible column types"));
 		}
 	    }
 	}

Modified: grass/trunk/vector/v.edit/a2b.c
===================================================================
--- grass/trunk/vector/v.edit/a2b.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/vector/v.edit/a2b.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -274,7 +274,7 @@
 }
 
 /**
-   \brief Close lines (boudaries)
+   \brief Close lines (boundaries)
    
    Using threshold distance (-1 for no limit)
    

Modified: grass/trunk/vector/v.edit/args.c
===================================================================
--- grass/trunk/vector/v.edit/args.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/vector/v.edit/args.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -170,7 +170,7 @@
 	_("For 'shorter' use negative threshold value, "
 	  "positive value for 'longer'");
     params->query->descriptions =
-	_("length;Select only lines or boudaries shorter"
+	_("length;Select only lines or boundaries shorter"
 	  "/longer than threshold distance;"
 	  "dangle;Select dangles shorter/longer than " "threshold distance");
     params->query->guisection = _("Query");

Modified: grass/trunk/vector/v.label.sa/main.c
===================================================================
--- grass/trunk/vector/v.label.sa/main.c	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/vector/v.label.sa/main.c	2008-09-29 17:31:56 UTC (rev 33598)
@@ -103,7 +103,7 @@
 
     p.hlcolor = G_define_option();
     p.hlcolor->key = "hcolor";
-    p.hlcolor->description = _("Hilight color for text");
+    p.hlcolor->description = _("Highlight color for text");
     p.hlcolor->type = TYPE_STRING;
     p.hlcolor->answer = "none";
     p.hlcolor->options =



More information about the grass-commit mailing list
--- grass/trunk/gui/wxpython/gui_modules/toolbars.py	2008-09-29 17:26:50 UTC (rev 33597)
+++ grass/trunk/gui/wxpython/gui_modules/toolbars.py	2008-09-29 17:31:56 UTC (rev 33598)
@@ -413,7 +413,7 @@
         # only one dialog can be open
         self.settingsDialog   = None
 
         # create toolbars (two rows optionaly)
         self.toolbar = []
         self.numOfRows = 1 # number of rows for toolbar
         for row in range(0, self.numOfRows):
@@ -1144,7 +1144,7 @@
         Update list of available vector map layers.
         This list consists only editable layers (in the current mapset)
 
-        Optionaly also update toolbar
+        Optionally also update toolbar
         """
 
         Debug.msg (4, "VDigitToolbar.UpdateListOfLayers(): updateTool=%d" % \
@@ -413,7 +413,7 @@
         self.settingsDialog   = None
 
-        # create toolbars (two rows optionaly)
+        # create toolbars (two rows optionally)
         self.toolbar = []
         self.numOfRows = 1 # number of rows for toolbar

Modified: grass/trunk/gui/wxpython/gui_modules/toolbox.py
===================================================================